using System;

namespace SpectralNet
{
	/// <summary>
	/// An edge between two nodes in a graph
	/// </summary>
	public class Edge 
	{
		/// <summary>
		/// Vertex one in the edge.
		/// </summary>
		public Vertex v1;

		/// <summary>
		/// Vertex two in the edge.
		/// </summary>
		public Vertex v2;

		/// <summary>
		/// String type of this edge...arbitrarily programmer-defined, but not used yet.
		/// </summary>
		string _type;

		/// <summary>
		/// The weight of this edge
		/// </summary>
		public double weight;

		/// <summary>
		/// Property wrapper for _type
		/// </summary>
		public string Type 
		{
			get { return _type; }
			set { _type = value; }
		}

		/// <summary>
		/// Should be .ToString()
		/// </summary>
		/// <returns>String representing this edge.</returns>
		public string Display() 
		{
			return v1.Label + "/" + v2.Label;
		}

		/// <summary>
		/// Edge constructor.
		/// 
		/// Note that the vertices have references added.
		/// </summary>
		/// <param name="node1">First node member of this edge.</param>
		/// <param name="node2">Second node member of this edge.</param>
		/// <param name="type">String type of this vertex</param>
		/*public Edge(Vertex node1, Vertex node2, string type) {
			v1 = node1;
			v2 = node2;

			if (v1.ConnectedTo.Contains(v2) == false)
			{
				v1.addRefToEdge(this);
			}

			if (v2.ConnectedTo.Contains(v1) == false)
			{
				v2.addRefToEdge(this);
			}

			weight = 1;

			_type = type;
		}*/

		/// <summary>
		/// Edge constructor.
		/// 
		/// Note that the vertices have references added.
		/// </summary>
		/// <param name="node1">First node member of this edge.</param>
		/// <param name="node2">Second node member of this edge.</param>
		/// <param name="type">String type of this vertex</param>
		/// <param name="edgeWeight">Weight of this edge</param>
		public Edge(Vertex node1, Vertex node2, string type, double edgeWeight) 
		{
			v1 = node1;
			v2 = node2;

			if (v1.ConnectedTo.Contains(v2) == false)
			{
				v1.addRefToEdge(this);
			}

			if (v2.ConnectedTo.Contains(v1) == false)
			{
				v2.addRefToEdge(this);
			}

			weight = edgeWeight;

			_type = type;
		}
	}

}
