using System;
using System.Collections;

namespace SpectralNet
{
	/// <summary>
	/// The SparseMatrix will be indexed FROM 0 TO SIZE-1, IT WILL **NOT** be indexed by node ID.  This is intended
	/// to be a GENERIC class.
	/// </summary>
	public class SparseMatrix 
	{
		/// <summary>
		/// The sortedlist that is this sparsematrix.
		/// </summary>
		SortedList[] adj;

		/// <summary>
		/// Gets M[i,j]
		/// </summary>
		/// <param name="i">First index.</param>
		/// <param name="j">Second index.</param>
		/// <returns>The value in the matrix.</returns>
		public double getValue(int i, int j) 
		{
			if (adj[i].ContainsKey(j)) 
			{
				return (double)(adj[i][j]);
			}

			return 0; // not found
		}

		/// <summary>
		/// Sets M[i,j]
		/// </summary>
		/// <param name="i">First index.</param>
		/// <param name="j">Second index.</param>
		/// <param name="value">The value in the matrix.</param>
		public void setValue(int i, int j, double value) 
		{
			if (adj[i].ContainsKey(j)) 
			{
				adj[i][j] = value;
			} 
			else 
			{
				adj[i].Add(j, value);
			}
		}

		/// <summary>
		/// Constructs a SparseMatrix.
		/// </summary>
		/// <param name="size">The size of this SparseMatrix.  *NOT* an estimate!</param>
		public SparseMatrix(int size) 
		{
			adj = new SortedList[size];

			for(int i = 0; i < size; i++) 
			{
				adj[i] = new SortedList();
			}
		}
	}

}
